%w=plotDensity(data, name, n)
%----------------------------
%
%Plot the density of states.
%
% data   band structure (see 'readBands')
% name   window title
% n      number of bins or zero for extrapolation
%           if not specified, extrapolation is choosen
%           whenever the velocity data is present, the
%           number of bins is set automatically else.
% w      figure handle
%
function w=plotDensity(data, name, n)
if ~nargin
   error('Unknown or undefined argument.');
end;
flag=isbands(data);
if flag > 7
   error('Band structure is corrupt.');
end;
if flag > 3
   fprintf('Band structure is damaged.\n');
end;
if nargin < 3
   n=[];
end;
[data,n]=density(data,n);  % compute density
a.Box='on';                % open figure
a.FontSize=15;
a.Layer='top';
a.LineStyleOrder='-';
a.NextPlot='replacechildren';
a.Position=[0.13 0.08 0.84 0.88];
a.TickDir='out';
a.TickDirMode='manual';
a.XLimMode='manual';
a.XTickLabelMode='manual';
a.XTickMode='manual';
w.IntegerHandle='off';
w.MinColormap=4;
w.NextPlot='replacechildren';
w.NumberTitle='off';
w.Position=[100 100 500 400];
w.Tag='Density of states';
if nargin < 2 | ~ischar(name)
   w.Name=w.Tag;
else
   w.Name=name;
end;
w=figure(w);
a=axes(a,'Parent',w);
ylabel('f [c/a]','Parent',a); % draw
if n
   h=barh(data.density(:,1),data.density(:,2),1);
   set(h,'EdgeColor',[0 0 0.5],'FaceColor',[0 0 0.75]);
else
   j=10^ceil(log10(max(data.density(:,2))));
   i=10^floor(log10(max(0.001,min(data.density(:,2)))));
   set(a,'XScale','log','XLim',[i j],'XTickMode','auto','XTickLabelMode','auto','Position',[0.13 0.1 0.84 0.86]);
   line([repmat(i,size(data.density,1),1) data.density(:,2)]',repmat(data.density(:,1),1,2)','Parent',a,'Color',[0 0 0.75]);
end;
